# pyPETaL-jav
The JAVELIN module for pyPetal.

[![PyPI](https://img.shields.io/pypi/v/pypetal-jav)](https://img.shields.io/pypi/v/pypetal-jav)





## Installation
pyPetal-jav is available on PyPI and can be installed with ``pip``:
```
    pip install --no-deps pypetal-jav
    pip install pypetal-jav
```

Or, if you want to install the latest development version:
```
    git clone https://github.com/Zstone19/pypetal-jav.git
    cd pypetal-jav
    pip install .
```

__NOTE:__ The user may need to install ``NumPy`` before installing pyPetal through ``pip`` or ``setup.py``. This is because ``JAVELIN`` requires ``NumPy`` in order to be installed. This can be done with:
```
    pip install numpy
```
